v4.2 release. (#2587)

* Fix default cluster callback values to 1 to avoid profiler failure when these values are not set in command line.

* v4.2 release.
This commit is contained in:
Junkai-Wu
2025-08-22 18:11:24 -04:00
committed by GitHub
parent 11cad1f67b
commit a49a78ffef
351 changed files with 28182 additions and 2032 deletions
+2 -2
View File
@@ -44,7 +44,7 @@ __global__ void
movm_test_device(uint16_t* g_in, uint16_t* g_out)
{
int tid = threadIdx.x;
// load input gmem -> register
uint32_t reg = reinterpret_cast<uint32_t*>(g_in)[tid];
@@ -128,7 +128,7 @@ TEST(SM75_CuTe_Turing, Movm)
//
// CuTe MOVM
//
{
thrust::device_vector<uint16_t> d_out(count);